%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Maastricht Optimization Toolbox
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

############
Introduction
############

.. include:: ../README.rst
   :start-line: 3


.. toctree::
    :maxdepth: 2
    :hidden:

    install
    changelog
    credits
